@@ -18,7 +18,7 @@ test_that("values", {
   expect_true(ps$check(list(d = 1, f = "a")))
   expect_equal(ps2$values, list(d = 0.5))
   # check printer
-  expect_output(print(ps2), "d.*<NoDefault>.*0.5")
+  expect_output(print(ps2), "d.*<NoDefault(?:\\[3\\])?>.*0.5")
 
   ps2 = ps$clone()
   ps2$subset(ids = c("i"))
